==> Smdn.Net.Imap4.Client-0.26.tar.bz2: Smdn.Net.Imap4.Client-0.26/Smdn.Net.Imap4/Smdn.Net.Imap4/ImapBodyDisposition.cs <==
// 
// Author:
//       smdn <smdn@mail.invisiblefulmoon.net>
// 
// Copyright (c) 2008-2010 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Collections.Generic;

using Smdn.Collections;

namespace Smdn.Net.Imap4 {
  public class ImapBodyDisposition {
    public string Type {
      get; private set;
    }

    public IDictionary<string, string> Parameters {
      get; private set;
    }

    public bool IsAttachment {
      get { return string.Equals(Type, "attachment", StringComparison.InvariantCultureIgnoreCase); }
    }

    public bool IsInline {
      get { return string.Equals(Type, "inline", StringComparison.InvariantCultureIgnoreCase); }
    }

    public string Filename {
      get
      {
        string filename;

        if (Parameters.TryGetValue("filename", out filename))
          return filename;
        else
          return null;
      }
    }

    public ImapBodyDisposition(string type, IDictionary<string, string> parameters)
    {
      if (type == null)
        throw new ArgumentNullException("type");
      if (parameters == null)
        throw new ArgumentNullException("parameters");

      this.Type = type;
      this.Parameters = (parameters ?? new Dictionary<string, string>()).AsReadOnly(StringComparer.InvariantCultureIgnoreCase);
    }

    public override string ToString ()
    {
      return string.Format("{{Type={0}, Parameters={1}}}", Type, Parameters.Count);
    }
  }
}

==> Smdn.Net.Imap4.Client-0.32.tar.bz2: Smdn.Net.Imap4.Client-0.32/Smdn.Net.Imap4/Smdn.Net.Imap4/ImapBodyDisposition.cs <==
// 
// Author:
//       smdn <smdn@mail.invisiblefulmoon.net>
// 
// Copyright (c) 2008-2010 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Collections.Generic;

using Smdn.Collections;

namespace Smdn.Net.Imap4 {
  public sealed class ImapBodyDisposition {
    public string Type {
      get; private set;
    }

    public IDictionary<string, string> Parameters {
      get; private set;
    }

    public bool IsAttachment {
      get { return string.Equals(Type, "attachment", StringComparison.OrdinalIgnoreCase); }
    }

    public bool IsInline {
      get { return string.Equals(Type, "inline", StringComparison.OrdinalIgnoreCase); }
    }

    public string Filename {
      get
      {
        string filename;

        if (Parameters.TryGetValue("filename", out filename))
          return filename;
        else
          return null;
      }
    }

    public ImapBodyDisposition(string type, IDictionary<string, string> parameters)
    {
      if (type == null)
        throw new ArgumentNullException("type");

      this.Type = type;
      this.Parameters = (parameters ?? new Dictionary<string, string>()).AsReadOnly(StringComparer.OrdinalIgnoreCase);
    }

    public override string ToString ()
    {
      return string.Format("{{Type={0}, Parameters={1}}}", Type, Parameters.Count);
    }
  }
}
